#
# Makefile Template for Tessy
# Compiler   : ANSI-C/cC++ Compiler for S12Z
# Environment: Codewarrior 10 (Freescale Semiconductor, Inc.)
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
METROWERKS_HOME := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
MODULE_PATH_DOS := $(shell ts_pathname -w '$(MODULE_PATH_DOS)')

TS_NAME         := TS_CODEWARRIOR
IDE_NAME        := codewarrior10
COMPANY_NAME    := metrowerks
PROCESSOR_NAME  := s12z

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all    : master slave
master : $(MODULE_PATH)\ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH)\ts_$(TESTOBJECT)_m.exe

#

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#
S_CC           := $(METROWERKS_HOME)\S12lisa_Tools\Build_Tools\mwccs12lisa.exe
S_LINK         := $(METROWERKS_HOME)\S12lisa_Tools\Build_Tools\linker.exe
S_INCLUDES     := -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS) \
                  -I- -I"$(METROWERKS_HOME)/S12lisa_Support/s12lisac/include" \
                  -I- -I"$(METROWERKS_HOME)/S12lisa_Support/s12lisac/src" \
                  -I- -I"$(METROWERKS_HOME)/S12lisa_Support/s12lisac/lib_$(MEMORY_MODEL)"
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)
S_COMP_OPTIONS := -O0 $(COMPILER_DIALECT) -g -nostdinc -nosyspath  -DTESSY -DTS_SLAVE \
                  -DTS_HC08 -DTS_HAVE_FLOAT64 -DTS_HAVE_FLOAT96 \
                  -model $(MEMORY_MODEL) -bfield_lsbit_first -bfield_reduce_type -opt level=0 \
                  -opt space -Cpp_Exceptions off -char unsigned -msgstyle parseable \
						-fp_compliant -double_size=8 -bit64_code_gen mem -MD -gccdep -w nocmdline
S_LINK_OPTIONS := -M "$(LINKER_FILE)" -ViewHidden

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -o "$@" "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o "$@"

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o "$@"


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o "$@"

#
# Handle Board Files
#
ifeq ("true","$(USE_BOARD_FILES)")
ifeq ("","$(INITOBJDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitObjDir' is empty.)
endif
INITOBJDIR := $(shell ts_pathname -s '$(INITOBJDIR)')
ifeq ("","$(INITSRCDIR)")
$(info Attribute 'InitSrcDir' is empty. Using objects for linking only.)
START_OBJS := $(wildcard $(INITOBJDIR)/*$(OBJFILE_EXTENSION))
else
INITSRCDIR := $(shell ts_pathname -s '$(INITSRCDIR)')
START_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
              $(patsubst $(INITSRCDIR)/%.asm,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.asm))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) $(S_INCLUDES) -I$(INITSRCDIR) $(S_COMP_OPTIONS) $< -o "$(shell ts_pathname -s '$@')"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.asm
	$(S_CC) $(S_INCLUDES) -I$(INITSRCDIR) $(S_COMP_OPTIONS) $< -o "$(shell ts_pathname -s '$@')"
endif
ifeq ("","$(START_OBJS)")
$(warning Attribute 'Use Board Files' is set to true but no objects were found.)
endif
endif


#
# Objects to be delete after the build process.
#
TS_INTERMEDIATE_OBJS := $(S_OBJECTS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
                        $(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT)
.INTERMEDIATE: $(TS_INTERMEDIATE_OBJS)


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(START_OBJS) $(TS_INTERMEDIATE_OBJS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(USER_LINK_OPTIONS) $(S_LINK_OPTIONS) \
						-Add($(S_OBJECTS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
						$(S_SRC_OBJECTS) "$(LIBRARY)" $(START_OBJS) $(S_UC_OBJECT) $(S_STUB_OBJECT)) \
						-O"$@"

#####################################################################
#END_TARGETS
#####################################################################
